@@ -75,7 +75,7 @@ namespace ompl
             StateSpace &operator=(const StateSpace &) = delete;
 
             /** \brief Define the type of state allocated by this space */
-            typedef ompl::base::State StateType;
+            using StateType = ompl::base::State;
 
             /** \brief Constructor. Assigns a @b unique name to the space */
             StateSpace();
@@ -262,17 +262,17 @@ namespace ompl
                 of the segments considered valid. The effect of this
                 function is immediate (setup() does not need to be
                 called). */
-            void setValidSegmentCountFactor(unsigned int factor);
+            virtual void setValidSegmentCountFactor(unsigned int factor);
 
             /** \brief Get the value used to multiply the return value of validSegmentCount().*/
-            unsigned int getValidSegmentCountFactor() const;
+            virtual unsigned int getValidSegmentCountFactor() const;
 
             /** \brief Get the longest valid segment at the time setup() was called. */
-            double getLongestValidSegmentLength() const;
+            virtual double getLongestValidSegmentLength() const;
 
             /** \brief Compute an array of ints that uniquely identifies the structure of the state space.
                 The first element of the signature is the number of integers that follow */
-            void computeSignature(std::vector<int> &signature) const;
+            virtual void computeSignature(std::vector<int> &signature) const;
 
             /** @} */
 
@@ -401,10 +401,10 @@ namespace ompl
 
             /** \brief Copy all the real values from a state \e source to the array \e reals using
              * getValueAddressAtLocation() */
-            void copyToReals(std::vector<double> &reals, const State *source) const;
+            virtual void copyToReals(std::vector<double> &reals, const State *source) const;
 
             /** \brief Copy the values from \e reals to the state \e destination using getValueAddressAtLocation() */
-            void copyFromReals(State *destination, const std::vector<double> &reals) const;
+            virtual void copyFromReals(State *destination, const std::vector<double> &reals) const;
 
             /** @} */
 
@@ -574,7 +574,7 @@ namespace ompl
         {
         public:
             /** \brief Define the type of state allocated by this state space */
-            typedef ompl::base::CompoundState StateType;
+            using StateType = ompl::base::CompoundState;
 
             /** \brief Construct an empty compound state space */
             CompoundStateSpace();
@@ -735,7 +735,7 @@ namespace ompl
             std::vector<StateSpacePtr> components_;
 
             /** \brief The number of components */
-            unsigned int componentCount_{0};
+            unsigned int componentCount_{0u};
 
             /** \brief The weight assigned to each component of the state space when computing the compound distance */
             std::vector<double> weights_;
